import { FoundationElement } from '@microsoft/fast-foundation';
import { componentType, LayoutComponent, RegistrationConfig } from '../utils';
/**
 * @public
 * `FoundationLayoutItem` is a custom element that represents an item in the layout.
 * @remarks
 * This element is used to wrap html elements and configure their layout settings as part of the layout system.
 *
 * This is a simple component which is only used to define the layout splits; any JavaScript API interactions or custom styling is used via {@link FoundationLayout}.
 * @tagname %%prefix%%-layout-item
 */
export declare class FoundationLayoutItem extends FoundationElement implements LayoutComponent {
    /**
     * Sets the title of the item which is displayed on the tab.
     * @remarks
     * Defaults to `Item ` + {@link FoundationLayoutItem.registration}
     * @public
     */
    title: string;
    /**
     * Boolean attribute controls whether the window can be closed in the GUI.
     * Defaults to `false`.
     * @public
     */
    closable: boolean;
    /**
     * optional string describing the size of the new item (see the written documentation for more info)
     * @public
     */
    size: string;
    /**
     * Sets the registration name for the item, which can be used later to add the item via the JavaScript API using {@link FoundationLayout.addItem}.
     * @remarks
     * Items added via the JavaScript API and HTML API share the same pool of registration names.
     * Using a duplicate registration name is a runtime error.
     * This registration name defaults to the number of the window it is.
     * It is highly recommended if you are using the JavaScript API that you set a registration name here manually.
     * @public
     */
    registration: string;
    /** @internal */
    [componentType]: "item";
    /** @internal */
    private slottedElements;
    /** @internal */
    connectedCallback(): void;
    /** @internal */
    private getParentLayoutComponent;
    /** @internal */
    requestLayoutReload(): void;
    /** @internal */
    cacheElementsAndRegister(config: RegistrationConfig): string;
}
/**
 * The FoundationLayoutItem Composed element
 *
 * @internal
 * @remarks
 * Can be registered with the design system via {@link foundationlayoutComponents}.
 * You do not need to compose your own version of this to update the styles of the layout.
 *
 * Tag Name: <{prefix}-layout-item>
 */
export declare const foundationLayoutItem: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<any, any>;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<any, any>;
}, typeof FoundationLayoutItem>;
//# sourceMappingURL=layout-item.d.ts.map