import { RootItemConfig } from '@genesis-community/golden-layout';
import { FoundationElement } from '@microsoft/fast-foundation';
import { componentType, LayoutComponent, LayoutRegionType, RegistrationConfig } from '../utils';
/**
 * @public
 * `FoundationLayoutRegion` is a custom element that represents a region in the layout.
 * @remarks
 * This element is used to create a region in the layout. It can be used to create a horizontal or vertical split, or a tabbed region.
 *
 * This is a simple component which is only used to define the layout splits; any JavaScript API interactions or custom styling is used via {@link FoundationLayout}.
 * @tagname %%prefix%%-layout-region
 */
export declare class FoundationLayoutRegion extends FoundationElement implements LayoutComponent {
    /**
     * optional string describing the size of the new item (see the written documentation for more info)
     * @public
     */
    size: string;
    /**
     * Defines the {@link LayoutRegionType | type} of the region.
     * Defaults to `horizontal`.
     * @public
     */
    type: LayoutRegionType;
    /** @internal */
    [componentType]: LayoutRegionType;
    /**
     * Reference to the config in the whole layout config for this
     * specific region.
     * @internal
     */
    private layoutConfig;
    /** @internal */
    connectedCallback(): void;
    /**
     * Gets the layout config for this region using {@link FoundationLayoutRegion.constructLayoutConfig} and adds it into the main config tree via the parents. It saves a reference to the this config so a child can add its config in later.
     * @internal
     */
    private setupLayoutRegion;
    /**
     * Creates a golden layout config for this object.
     * @internal
     */
    private constructLayoutConfig;
    /** @internal */
    private getParentLayoutComponent;
    /** @internal */
    addItemFromChild<T extends RootItemConfig>(item: T): T;
    /** @internal */
    requestLayoutReload(): void;
    /** @internal */
    cacheElementsAndRegister(config: RegistrationConfig): string;
}
/**
 * The FoundationLayoutRegion Composed element
 *
 * @internal
 * @remarks
 * Can be registered with the design system via {@link foundationlayoutComponents}.
 * You do not need to compose your own version of this to update the styles of the layout.
 *
 * Tag Name: <{prefix}-layout-region>
 */
export declare const foundationLayoutRegion: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<any, any>;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<any, any>;
}, typeof FoundationLayoutRegion>;
//# sourceMappingURL=layout-region.d.ts.map