import { foundationLayoutItem } from './layout-item';
import { foundationLayout } from './layout-main';
import { foundationLayoutRegion } from './layout-region';
/**
 * Registration object to register the layout with your design system.
 *
 * @remarks
 * Registers the three layout component types with the design system.
 * You require to use the prefix of the design system with each tag.
 * If you wish to alternate the styles of the layout you only need to compose your own custom
 * version of {@link FoundationLayout} as this contains the styles for the entire layout.
 *
 * @example
 * `<zero-layout></zero-layout>` if you are using the layout with the `zero` design-system.
 *
 * @public
 */
export const foundationLayoutComponents = {
    foundationLayout,
    foundationLayoutRegion,
    foundationLayoutItem,
    register(container, ...rest) {
        if (!container) {
            // preserve backward compatibility with code that loops through
            // the values of this object and calls them as funcs with no args
            return;
        }
        for (const key in this) {
            if (key === 'register') {
                continue;
            }
            this[key]().register(container, ...rest);
        }
    },
};
