var _a;
import { __decorate } from "tslib";
import { attr } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { componentType, getParentLayoutComponent, wrapperTemplate, } from '../utils';
/**
 * @public
 * `FoundationLayoutItem` is a custom element that represents an item in the layout.
 * @remarks
 * This element is used to wrap html elements and configure their layout settings as part of the layout system.
 *
 * This is a simple component which is only used to define the layout splits; any JavaScript API interactions or custom styling is used via {@link FoundationLayout}.
 * @tagname %%prefix%%-layout-item
 */
export class FoundationLayoutItem extends FoundationElement {
    constructor() {
        super(...arguments);
        /**
         * Boolean attribute controls whether the window can be closed in the GUI.
         * Defaults to `false`.
         * @public
         */
        this.closable = false;
        /** @internal */
        this[_a] = 'item';
    }
    /** @internal */
    connectedCallback() {
        var _b;
        super.connectedCallback();
        this.slottedElements = this.shadowRoot.querySelector('slot.target').assignedElements();
        const registeredID = this.cacheElementsAndRegister({
            elements: this.slottedElements,
            id: this.registration,
        });
        const itemConfig = {
            type: 'component',
            componentType: registeredID,
            title: (_b = this.title) !== null && _b !== void 0 ? _b : `Item ${registeredID}`,
            reorderEnabled: true,
            isClosable: this.closable,
            size: this.size,
        };
        this.getParentLayoutComponent().addItemFromChild(itemConfig);
        this.requestLayoutReload();
    }
    /** @internal */
    getParentLayoutComponent() {
        return getParentLayoutComponent.apply(this);
    }
    /** @internal */
    requestLayoutReload() {
        this.getParentLayoutComponent().requestLayoutReload();
    }
    /** @internal */
    cacheElementsAndRegister(config) {
        return this.getParentLayoutComponent().cacheElementsAndRegister(config);
    }
}
_a = componentType;
__decorate([
    attr
], FoundationLayoutItem.prototype, "title", void 0);
__decorate([
    attr({ mode: 'boolean' })
], FoundationLayoutItem.prototype, "closable", void 0);
__decorate([
    attr
], FoundationLayoutItem.prototype, "size", void 0);
__decorate([
    attr
], FoundationLayoutItem.prototype, "registration", void 0);
/**
 * The FoundationLayoutItem Composed element
 *
 * @internal
 * @remarks
 * Can be registered with the design system via {@link foundationlayoutComponents}.
 * You do not need to compose your own version of this to update the styles of the layout.
 *
 * Tag Name: <{prefix}-layout-item>
 */
export const foundationLayoutItem = FoundationLayoutItem.compose({
    baseName: 'layout-item',
    template: wrapperTemplate,
});
