// NOTE: This file is stylelint ignored as the css class names that golden layout use go against the rules
import { accentFillRest, controlCornerRadius, neutralLayer1, neutralLayer3, neutralLayer4, } from '@microsoft/fast-components';
import { css } from '@microsoft/fast-element';
import { maximisSVG, minimiseSVG, closeSVG, tabDropdownSVG } from './constants';
const containerStyles = `
 :host {
    contain: content;
    display: block;
    position: relative;
    height: 100%;
    width: 100%;
  }
  .layout-container {
    position: absolute;
    height: 100%;
    width: 100%;
    inset: 0px;
  }
`;
const loadingSpinnerStyles = css `
  * {
    --spinner-size: 50px;
  }

  .html-spinner {
    width: var(--spinner-size);
    height: var(--spinner-size);
    border: 4px solid white;
    border-top: 4px solid ${accentFillRest};
    border-radius: 50%;
  }

  .html-spinner {
    -webkit-transition-property: -webkit-transform;
    -webkit-transition-duration: 1.2s;
    -webkit-animation-name: rotate;
    -webkit-animation-iteration-count: infinite;
    -webkit-animation-timing-function: linear;

    -moz-transition-property: -moz-transform;
    -moz-animation-name: rotate;
    -moz-animation-duration: 1.2s;
    -moz-animation-iteration-count: infinite;
    -moz-animation-timing-function: linear;

    transition-property: transform;
    animation-name: rotate;
    animation-duration: 1.2s;
    animation-iteration-count: infinite;
    animation-timing-function: linear;
  }

  @-webkit-keyframes rotate {
    from {
      -webkit-transform: rotate(0deg);
    }
    to {
      -webkit-transform: rotate(360deg);
    }
  }

  @-moz-keyframes rotate {
    from {
      -moz-transform: rotate(0deg);
    }
    to {
      -moz-transform: rotate(360deg);
    }
  }

  @keyframes rotate {
    from {
      transform: rotate(0deg);
    }
    to {
      transform: rotate(360deg);
    }
  }

  /* spinner positioning */

  .html-spinner {
    position: absolute;
    z-index: 5;
    left: calc(50% - (calc(var(--spinner-size) / 2)));
    top: calc(50% - (calc(var(--spinner-size) / 2)));
  }
`;
/**
 * `ElementStyles` which defines the css for {@link FoundationLayout}.
 * @remarks
 * Can be used in a composition to customise the styles of the layout.
 * @public
 */
export const layoutStyles = css `
  ${containerStyles}
  ${loadingSpinnerStyles}

  .lm_goldenlayout {
    padding: 1px;
    background: ${neutralLayer1};
    border-radius: calc(${controlCornerRadius} * 1.5px);
  }

  .lm_stack.lm_item {
    background-color: ${neutralLayer4};
    border-radius: calc(${controlCornerRadius} * 1.5px);
  }
  .lm_maximised .lm_header {
    background-color: ${neutralLayer4};
    border-radius: calc(${controlCornerRadius} * 1.5px);
    position: unset;
  }

  .lm_maximised .lm_header .lm_tabs {
    z-index: 3;
  }

  .lm_content {
    background-color: ${neutralLayer3};
    border-radius: calc(${controlCornerRadius} * 1.5px);
    border: 1px solid;
    border-color: #2e3339;
    box-sizing: border-box;
  }

  .lm-header {
    z-index: 1;
  }
  .lm_header .lm_tabs {
    padding: 0 16px;
  }

  .lm_stack > .lm_items {
    z-index: 2;
    box-shadow: 0px -1px 15px rgba(0, 0, 0, 0.35);
  }

  .lm_header .lm_tab.lm_active.lm_focused {
    background-color: ${neutralLayer3};
  }
  .lm_header .lm_tab.lm_active {
    background-color: ${neutralLayer3};
    border: 1px solid;
    border-color: #2e3339;
    border-bottom: 0;
    color: ${accentFillRest};
  }

  .lm_header .lm_tab {
    align-items: center;
    background-color: ${neutralLayer4};
    border: 1px solid;
    border-bottom-color: #2e3339;
    border-bottom: 0px solid;
    border-color: rgba(0, 0, 0, 0.35);
    border-radius: calc(${controlCornerRadius} * 1.5px) calc(${controlCornerRadius} * 1.5px) 0 0;
    box-shadow: 1px -1px 2px rgba(0, 0, 0, 0.35);
    color: rgba(255, 255, 255, 0.3);
    display: flex;
    font-family: inherit;
    font-size: 13px;
    font-weight: 700;
    height: 30px;
    margin-right: 2px;
    margin-top: 3px;
    padding: 2px 16px;
  }

  .lm_header .lm_tab:not(.lm_active):hover {
    background-color: rgba(255, 255, 255, 0.1);
    color: #f1f1f1;
  }

  .lm_header .lm_controls {
    top: 4px;
    display: flex;
  }
  .lm_header .lm_controls > * {
    width: 30px;
    height: 30px;
    background-repeat: no-repeat;
    background-position: center;
    background-size: 16px;
    background-color: rgba(255, 255, 255, 0.03);
    border-radius: calc(${controlCornerRadius} * 1.5px);
    margin-right: 4px;
    top: 3px;
    opacity: 1;
  }
  .lm_header .lm_controls > *:hover {
    background-color: rgba(255, 255, 255, 0.1);
    cursor: pointer;
  }

  .lm_controls .lm_maximise {
    background-image: url('${maximisSVG}');
  }
  .lm_maximised .lm_controls .lm_maximise {
    background-image: url('${minimiseSVG}');
  }
  .lm_controls .lm_close {
    background-image: url('${closeSVG}');
  }
  .lm_header .lm_tab .lm_close_tab {
    background-image: url('${closeSVG}');
    background-size: 10px;
    background-repeat: no-repeat;
    margin-left: 12px;
    position: relative;
    top: 0;
    right: 0;
  }

  .lm_header .lm_tab.lm_active {
    padding: 4px 25px 3px 10px;
  }

  .lm_header .lm_tab:not(.lm_active) .lm_title {
    color: ${accentFillRest};
    opacity: 0.7;
  }

  .lm_header .lm_controls .lm_tabdropdown::before {
    content: none;
  }
  .lm_header .lm_controls .lm_tabdropdown {
    background-image: url('${tabDropdownSVG}');
  }
  .lm_header .lm_tabdropdown_list {
    top: 38px;
    right: 108px;
    background-color: ${neutralLayer3};
    border: 1px solid;
    border-color: #2e3339;
    border-radius: calc(${controlCornerRadius} * 1.5px);
    box-shadow: 0px 5px 15px rgba(0, 0, 0, 0.35);
  }
  .lm_header .lm_tabdropdown_list > .lm_tab {
    box-shadow: none;
    padding: 0 16px;
    white-space: nowrap;
    background-color: transparent;
    color: #c9c9c9;
    height: 36px;
    border-radius: 0;
    overflow: visible;
    text-overflow: normal;
  }
  .lm_header .lm_tabdropdown_list > .lm_tab:last-child {
    border-bottom: 0;
  }

  /* gl base styles start */
  .lm_root {
    position: relative;
  }
  .lm_row > .lm_item {
    float: left;
  }
  .lm_content {
    overflow: hidden;
    position: relative;
  }
  .lm_dragging,
  .lm_dragging * {
    cursor: move !important;
    user-select: none;
  }
  .lm_maximised {
    left: 0;
    padding: 1px;
    position: absolute;
    top: 0;
    z-index: 40;
  }
  .lm_maximise_placeholder {
    display: none;
  }
  .lm_splitter {
    position: relative;
    z-index: 20;
  }
  .lm_splitter:hover,
  .lm_splitter.lm_dragging {
    background: ${accentFillRest};
    border-radius: calc(${controlCornerRadius} * 4px);
  }
  .lm_splitter.lm_vertical .lm_drag_handle {
    width: 100%;
    height: 15px;
    position: absolute;
    top: -5px;
    cursor: ns-resize;
  }
  .lm_splitter.lm_horizontal {
    float: left;
    height: 100%;
  }
  .lm_splitter.lm_horizontal .lm_drag_handle {
    width: 15px;
    height: 100%;
    position: absolute;
    left: -5px;
    cursor: ew-resize;
  }
  .lm_header {
    overflow: visible;
    position: relative;
    z-index: 1;
  }
  .lm_header [class^='lm_'] {
    box-sizing: content-box !important;
  }
  .lm_header .lm_controls {
    position: absolute;
    right: 3px;
  }
  .lm_header .lm_controls > li {
    cursor: pointer;
    float: left;
    width: 18px;
    height: 18px;
    text-align: center;
  }
  .lm_header ul {
    margin: 0;
    padding: 0;
    list-style-type: none;
  }
  .lm_header .lm_tabs {
    position: absolute;
  }
  .lm_header .lm_tab {
    cursor: pointer;
    float: left;
    margin-top: 1px;
    padding: 3px 25px 3px 10px;
    position: relative;
  }
  .lm_header .lm_tab i {
    width: 2px;
    height: 19px;
    position: absolute;
  }
  .lm_header .lm_tab i.lm_left {
    top: 0;
    left: -2px;
  }
  .lm_header .lm_tab i.lm_right {
    top: 0;
    right: -2px;
  }
  .lm_header .lm_tab .lm_title {
    display: inline-block;
    overflow: hidden;
    text-overflow: ellipsis;
  }
  .lm_header .lm_tab .lm_title:only-child {
    padding-left: 10px;
  }
  .lm_header .lm_tab .lm_close_tab {
    width: 14px;
    height: 14px;
    position: absolute;
    top: 11px;
    right: 0;
    text-align: center;
  }
  .lm_stack.lm_left .lm_header,
  .lm_stack.lm_right .lm_header {
    height: 100%;
  }
  .lm_dragProxy.lm_left .lm_header,
  .lm_dragProxy.lm_right .lm_header,
  .lm_stack.lm_left .lm_header,
  .lm_stack.lm_right .lm_header {
    width: 20px;
    float: left;
    vertical-align: top;
  }
  .lm_dragProxy.lm_left .lm_header .lm_tabs,
  .lm_dragProxy.lm_right .lm_header .lm_tabs,
  .lm_stack.lm_left .lm_header .lm_tabs,
  .lm_stack.lm_right .lm_header .lm_tabs {
    transform-origin: left top;
    top: 0;
    width: 1000px;
  }
  .lm_dragProxy.lm_left .lm_header .lm_controls,
  .lm_dragProxy.lm_right .lm_header .lm_controls,
  .lm_stack.lm_left .lm_header .lm_controls,
  .lm_stack.lm_right .lm_header .lm_controls {
    bottom: 0;
  }
  .lm_dragProxy.lm_left .lm_items,
  .lm_dragProxy.lm_right .lm_items,
  .lm_stack.lm_left .lm_items,
  .lm_stack.lm_right .lm_items {
    float: left;
  }
  .lm_dragProxy.lm_left .lm_header .lm_tabs,
  .lm_stack.lm_left .lm_header .lm_tabs {
    transform: rotate(-90deg) scaleX(-1);
    left: 0;
  }
  .lm_dragProxy.lm_left .lm_header .lm_tabs .lm_tab,
  .lm_stack.lm_left .lm_header .lm_tabs .lm_tab {
    transform: scaleX(-1);
    margin-top: 1px;
  }
  .lm_dragProxy.lm_left .lm_header .lm_tabdropdown_list,
  .lm_stack.lm_left .lm_header .lm_tabdropdown_list {
    top: initial;
    right: initial;
    left: 20px;
  }
  .lm_dragProxy.lm_right .lm_content {
    float: left;
  }
  .lm_dragProxy.lm_right .lm_header .lm_tabs,
  .lm_stack.lm_right .lm_header .lm_tabs {
    transform: rotate(90deg) scaleX(1);
    left: 100%;
    margin-left: 0;
  }
  .lm_dragProxy.lm_right .lm_header .lm_controls,
  .lm_stack.lm_right .lm_header .lm_controls {
    left: 3px;
  }
  .lm_dragProxy.lm_right .lm_header .lm_tabdropdown_list,
  .lm_stack.lm_right .lm_header .lm_tabdropdown_list {
    top: initial;
    right: 20px;
  }
  .lm_dragProxy.lm_bottom .lm_header .lm_tab,
  .lm_stack.lm_bottom .lm_header .lm_tab {
    margin-top: 0;
    border-top: none;
  }
  .lm_dragProxy.lm_bottom .lm_header .lm_controls,
  .lm_stack.lm_bottom .lm_header .lm_controls {
    top: 3px;
  }
  .lm_dragProxy.lm_bottom .lm_header .lm_tabdropdown_list,
  .lm_stack.lm_bottom .lm_header .lm_tabdropdown_list {
    top: initial;
    bottom: 20px;
  }
  .lm_drop_tab_placeholder {
    float: left;
    width: 100px;
    height: 10px;
    visibility: hidden;
  }
  .lm_header .lm_tabdropdown_list {
    position: absolute;
    top: 20px;
    right: 0;
    z-index: 5;
    overflow: hidden;
  }
  .lm_header .lm_tabdropdown_list .lm_tab {
    clear: both;
    padding-right: 10px;
    margin: 0;
  }
  .lm_header .lm_tabdropdown_list .lm_tab .lm_title {
    width: 100px;
  }
  .lm_header .lm_tabdropdown_list .lm_close_tab {
    display: none !important;
  }
  .lm_dragProxy {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 30;
  }
  .lm_dragProxy .lm_header {
    background: transparent;
  }
  .lm_dragProxy .lm_content {
    border-top: none;
    overflow: hidden;
  }
  .lm_dropTargetIndicator {
    display: none;
    position: absolute;
    z-index: 20;
  }
  .lm_dropTargetIndicator .lm_inner {
    width: 100%;
    height: 100%;
    position: relative;
    top: 0;
    left: 0;
  }
  .lm_transition_indicator {
    display: none;
    width: 20px;
    height: 20px;
    position: absolute;
    top: 0;
    left: 0;
    z-index: 20;
  }
  .lm_popin {
    width: 20px;
    height: 20px;
    position: absolute;
    bottom: 0;
    right: 0;
    z-index: 9999;
  }
  .lm_popin > * {
    width: 100%;
    height: 100%;
    position: absolute;
    top: 0;
    left: 0;
  }
  .lm_popin > .lm_bg {
    z-index: 10;
  }
  .lm_popin > .lm_icon {
    z-index: 20;
  } /*# sourceMappingURL=goldenlayout-base.css.map */
`;
